# velovi

[![Stars](https://img.shields.io/github/stars/YosefLab/velovi?logo=GitHub&color=yellow)](https://github.com/YosefLab/velovi/stargazers)
[![Documentation Status](https://readthedocs.org/projects/velovi/badge/?version=latest)](https://velovi.readthedocs.io/en/stable/?badge=stable)
![Build Status](https://github.com/YosefLab/velovi/workflows/velovi/badge.svg)
[![codecov](https://codecov.io/gh/YosefLab/velovi/branch/main/graph/badge.svg?token=BGI9Z8R11R)](https://codecov.io/gh/YosefLab/velovi)
[![Code Style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/python/black)

Variational inference for RNA velocity. This is an experimental repo for the veloVI model. Installation instructions and tutorials are in the docs. Over the next few months veloVI will move into [scvi-tools](https://scvi-tools.org/), and wrappers wil be built in [scVelo](https://scvelo.org/).
